]> mj.ucw.cz Git - leo.git/blobdiff - css.h
css.h: Fixed a wrong type
[leo.git] / css.h
diff --git a/css.h b/css.h
index d35c0b36156ee1509014516545003914997398a3..1cd76afd93756a598309146f7879e3639cbbc0df 100644 (file)
--- a/css.h
+++ b/css.h
@@ -4,8 +4,8 @@
  *     (c) 2014 Martin Mares <mj@ucw.cz>
  */
 
-#ifndef _BRUM_CSS_H
-#define _BRUM_CSS_H
+#ifndef _LEO_CSS_H
+#define _LEO_CSS_H
 
 #include "osm.h"
 #include "style.h"
@@ -38,7 +38,7 @@ enum css_object_type {
 
 struct css_path {
   cnode n;
-  enum osm_object_type type;   // Object type or OSM_TYPE_ANY
+  enum css_object_type type;   // Object type or CSS_TYPE_ANY
   clist conditions;            // Attribute conditions
   layer_t layer;               // STYLE_LAYER_xxx or more
   osm_val_t role;